#
# spec file for package impressive
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define dist_name Impressive
Name:           impressive
Version:        0.13.1
Release:        bp155.1.6
Summary:        PDF and image viewer optimized for presentations
License:        GPL-2.0-only
Group:          Productivity/Office/Other
URL:            http://impressive.sourceforge.net/
Source0:        http://downloads.sourceforge.net/project/%{name}/%{dist_name}/%{version}/%{dist_name}-%{version}.tar.gz
Requires:       ghostscript
Requires:       python3-imaging
Requires:       python3-opengl
Requires:       python3-pygame
Recommends:     mupdf
BuildArch:      noarch

%description
Impressive is a program that displays presentation slides.
Features:
- Page transitions
- Overview screen
- Highlight boxes
- Spotlight effect

%prep
%autosetup -p1 -n %{dist_name}-%{version}

sed -i 's/env python$/python3/' impressive.py

%build

%install
install -Dm 0755 %{name}.py %{buildroot}%{_bindir}/%{name}
install -Dm 0644 %{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1

%files
%license license.txt
%doc changelog.txt demo.pdf
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Sun Mar 20 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.13.1
  * support for SDL 2 via PyGame 2.0
  * many fixes in native library path detection
  * new option --background to set display background color
  * fixed crash with page title extraction in PDF files with broken
    text encoding
  * fixed mouse hiding (--mousedelay 1) not working properly;
    added -N/--nocursor as an alias for that
  * --mousedelay now also works in windowed mode
  * software mouse cursor is hidden too when the mouse leaves
    the window
  * fixed interactive toggling of the "no-overview" (O key) and
    "skip" (I key)
    properties from overview page (they acted on the wrong page)
  * 'transition' PageProps can now be strings instead of direct
    class references
  * basic support for Raspberry Pi 1-3 with KMS graphics drivers
  * improved library version number and crash reporting
  * removed bytecode version again due to compatibility issues
* Mon Jul  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.13.0-beta2
  * added 'prev' and 'next' PageProps to change order of pages
  * fixed many remaining Python 3 compatibility issues
  * added "pseudo-binary" version (actually compressed bytecode) in the source
    release archive (requires Python 3)
  * circumvent blurry fonts on Windows due to high-DPI scaling
  * fixed crash in overview page handling when presentations have very many pages
  * fixed box-zoom mode display error in half-page mode
* Tue May 12 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Update to 0.13.0-beta1
  * Python 3 compatibility: should work with Python 2.7 and >= 3.6 now
  * Win32 build uses 64-bit Python 3
  * improved support for non-ASCII characters in page titles (as extracted
  * with pdftk)
  * fixed box-zoom mode display error in half-page mode
  * added option to set last page of page progress bar (--progress-last)
  * added separate overview animation time option (--overtime)
  * can now have multiple progress bars at once
  - page progress is moved to top of screen if any other bar is visible
  - "auto progress" is stacked over duration bar if both are visible
* Tue Oct  1 2019 Jan Engelhardt <jengelh@inai.de>
- Fix description typography. Drop redundant %%attr.
* Mon Sep 30 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.12.1:
  * fixed crash in crash reporter with recent Pillow versions
  * fixed crash with recent PyGame versions when non-latin characters appeared
    in slide titles
  * fixed page rotation
  * fixed -x/--fade mode
  * fixed directory playback mode
  * basic Raspberry Pi 4 compatibility (untested; requires X11)
  * more robust PDF hyperlink parser (page boxes can now be PDF references)
  * added option to temporarily inhibit automatic slideshows
  * default keybinding: [A] key, actions: auto-start, auto-stop, auto-toggle
- Run spec-cleaner
* Wed Apr 24 2019 Gary Ching-Pang Lin <glin@suse.com>
- Update to version 0.12.0
  + box-zoom mode: use Ctrl+LMB-drag to draw a box and zoom it to
    fit the screen; everything else is darkened
  + support for fractional zoom levels
  + ability to zoom further in than the hardware's maximum texture
    size
  + mouse wheel zooming
  + allow videos in the file list (in addition to PDF files and
    images)
  + added --time-display option: start with time display and
    tracking
  + fixed excessive mouse sensitivity in full-screen mode
  + fixed crashes when clicking hyperlinks in some PDFs
  + fixed non-working hyperlinks when more than one input document
    is specified
  + added new MuPDF renderer, uses no temporary files or named
    pipes on POSIX with MuPDF >= 1.4
  + can now use MuPDF's mutool instead of pdftk to get basic file
    information and unpack PDF files (for hyperlink decoding)
  + added --noquit option to prevent accidental single-key quitting
  + first page is now shown as early as possible (before fonts
    etc. have been preloaded)
- Replace pdftk with mupdf
* Tue Feb 16 2016 glin@suse.com
- Update to version 0.11.1
  + fix for newer PIL/Pillow versions that broke compatibility by
    removing .tostring() and .fromstring()
  + fixed crash when clicking on run: URI hyperlinks
  + PDF hyperlinks with file:// and run:// URIs now work correctly
    with quoted characters (e.g. spaces) in paths
  + added top-level synchronize() function to schedule calls in
    Impressive's main thead (useful for library mode)
  + early lookup of OpenGL vendor/renderer/version strings (to get
    more useful crash logs)
  + fixed SDL library lookup issue on newer Linux systems
  + OSD font lookup now works if the same font file exists multiple
    times in the font path
  + fixed crash when no OSD font is available
  + full port from OpenGL 1.1 to OpenGL (ES) 2.0
  + fully customizable key/mouse bindings (-e/--bind,
  - E/--controls, --control-help, --evtest)
  + MuPDF (mudraw/pdfdraw) rendering backend
  + 'transition' PageProp describes transition *to* the page, not
    after the page
  + Raspberry Pi compatibility
  + new shader-based blurring with desaturation + fallback to old
    method for old HW (autodetect or --noblur)
  + re-implemented all transitions with shaders
    (missing: PageTurn, SpinOutIn, SpiralOutIn, ZoomOutIn;
    new: WipeClouds, WipeBrightness1, WipeBrightness2)
  + compressed in-memory cache (-cz / --cache compressed)
  + removed -e/--noext and -R/--meshres due to obsolescence
  + --tracking enables time tracking right from the start
  + added -v/--verbose mode
  + MuPDF renderer backend can work via named pipes instead of
    temp files on Unix
  + alternate overview downscaling algorithm for slower systems
    (auto-detected)
  + internal default mouse cursor image
  + fixed OSD font rendering bug with Pillow
  + most platform-specific code now handled by abstraction layer;
    no direct PyGame calls in core
  + custom ctypes-based OpenGL loader instead of PyOpenGL
  + generic PDF renderer framework (necessary now that there's 3
    renderers)
  + external PDF renderers are now called with 'nice' when
    background rendering on POSIX
* Fri Oct  3 2014 tchvatal@suse.com
- Update to version 0.10.5:
  * unknown changelog
- Cleanup with spec-cleaner
- Install the binary without py suffix
* Sat Dec  1 2012 mailaender@opensuse.org
- update to version 0.10.3
* Wed Aug 12 2009 code933k@gmail.com
- Initial package.
